@@ -18,5 +18,5 @@ func TestIssueCmd(t *testing.T) {
 
 	out := test.ReturnBuffer(old, r, w)
 
-	assert.Contains(t, out, "Work with GitLab issues\n")
+	assert.Contains(t, out, "Work with GitLab issues.\n")
 }
