@@ -6,6 +6,7 @@ import (
 	"net/http"
 	"time"
 
+	"gitlab.com/gitlab-org/cli/pkg/dbg"
 	"gitlab.com/gitlab-org/cli/pkg/surveyext"
 
 	"github.com/AlecAivazis/survey/v2"
@@ -83,13 +84,14 @@ func NewCmdMerge(f *cmdutils.Factory) *cobra.Command {
 			}
 
 			if err = mrutils.MRCheckErrors(mr, mrutils.MRCheckErrOptions{
-				WorkInProgress: true,
+				Draft:          true,
 				Closed:         true,
 				Merged:         true,
 				Conflict:       true,
 				PipelineStatus: true,
 				MergePrivilege: true,
 			}); err != nil {
+				dbg.Debug("MRCheckErrors failed")
 				return err
 			}
 
@@ -244,7 +246,7 @@ func NewCmdMerge(f *cmdutils.Factory) *cobra.Command {
 				}
 				fmt.Fprintln(f.IO.StdOut, c.GreenCheck(), action)
 			}
-			fmt.Fprintln(f.IO.StdOut, mrutils.DisplayMR(c, mr, f.IO.IsaTTY))
+			fmt.Fprintln(f.IO.StdOut, mrutils.DisplayMR(c, &mr.BasicMergeRequest, f.IO.IsaTTY))
 			return nil
 		},
 	}
