@@ -8,7 +8,7 @@ import (
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
 
 	"github.com/stretchr/testify/assert"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
@@ -18,13 +18,13 @@ import (
 func Test_DisplayMR(t *testing.T) {
 	testCases := []struct {
 		name        string
-		mr          *gitlab.MergeRequest
+		mr          *gitlab.BasicMergeRequest
 		output      string
 		outputToTTY bool
 	}{
 		{
 			name: "opened",
-			mr: &gitlab.MergeRequest{
+			mr: &gitlab.BasicMergeRequest{
 				IID:          1,
 				State:        "opened",
 				Title:        "This is open",
@@ -36,7 +36,7 @@ func Test_DisplayMR(t *testing.T) {
 		},
 		{
 			name: "merged",
-			mr: &gitlab.MergeRequest{
+			mr: &gitlab.BasicMergeRequest{
 				IID:          2,
 				State:        "merged",
 				Title:        "This is merged",
@@ -48,7 +48,7 @@ func Test_DisplayMR(t *testing.T) {
 		},
 		{
 			name: "closed",
-			mr: &gitlab.MergeRequest{
+			mr: &gitlab.BasicMergeRequest{
 				IID:          3,
 				State:        "closed",
 				Title:        "This is closed",
@@ -60,7 +60,7 @@ func Test_DisplayMR(t *testing.T) {
 		},
 		{
 			name: "non-tty terse output",
-			mr: &gitlab.MergeRequest{
+			mr: &gitlab.BasicMergeRequest{
 				IID:          4,
 				State:        "open",
 				Title:        "This shouldn't be visible",
@@ -90,19 +90,23 @@ func Test_MRCheckErrors(t *testing.T) {
 		{
 			name: "draft",
 			mr: &gitlab.MergeRequest{
-				IID:            1,
-				WorkInProgress: true,
+				BasicMergeRequest: gitlab.BasicMergeRequest{
+					IID:   1,
+					Draft: true,
+				},
 			},
 			errOpts: MRCheckErrOptions{
-				WorkInProgress: true,
+				Draft: true,
 			},
 			output: "this merge request is still a draft. Run `glab mr update 1 --ready` to mark it as ready for review.",
 		},
 		{
 			name: "pipeline",
 			mr: &gitlab.MergeRequest{
-				IID:                       1,
-				MergeWhenPipelineSucceeds: true,
+				BasicMergeRequest: gitlab.BasicMergeRequest{
+					IID:                       1,
+					MergeWhenPipelineSucceeds: true,
+				},
 				Pipeline: &gitlab.PipelineInfo{
 					Status: "failure",
 				},
@@ -115,8 +119,10 @@ func Test_MRCheckErrors(t *testing.T) {
 		{
 			name: "merged",
 			mr: &gitlab.MergeRequest{
-				IID:   1,
-				State: "merged",
+				BasicMergeRequest: gitlab.BasicMergeRequest{
+					IID:   1,
+					State: "merged",
+				},
 			},
 			errOpts: MRCheckErrOptions{
 				Merged: true,
@@ -126,8 +132,10 @@ func Test_MRCheckErrors(t *testing.T) {
 		{
 			name: "closed",
 			mr: &gitlab.MergeRequest{
-				IID:   1,
-				State: "closed",
+				BasicMergeRequest: gitlab.BasicMergeRequest{
+					IID:   1,
+					State: "closed",
+				},
 			},
 			errOpts: MRCheckErrOptions{
 				Closed: true,
@@ -137,8 +145,10 @@ func Test_MRCheckErrors(t *testing.T) {
 		{
 			name: "opened",
 			mr: &gitlab.MergeRequest{
-				IID:   1,
-				State: "opened",
+				BasicMergeRequest: gitlab.BasicMergeRequest{
+					IID:   1,
+					State: "opened",
+				},
 			},
 			errOpts: MRCheckErrOptions{
 				Opened: true,
@@ -148,7 +158,9 @@ func Test_MRCheckErrors(t *testing.T) {
 		{
 			name: "subscribed",
 			mr: &gitlab.MergeRequest{
-				IID:        1,
+				BasicMergeRequest: gitlab.BasicMergeRequest{
+					IID: 1,
+				},
 				Subscribed: true,
 			},
 			errOpts: MRCheckErrOptions{
@@ -159,7 +171,9 @@ func Test_MRCheckErrors(t *testing.T) {
 		{
 			name: "unsubscribed",
 			mr: &gitlab.MergeRequest{
-				IID:        1,
+				BasicMergeRequest: gitlab.BasicMergeRequest{
+					IID: 1,
+				},
 				Subscribed: false,
 			},
 			errOpts: MRCheckErrOptions{
@@ -170,7 +184,9 @@ func Test_MRCheckErrors(t *testing.T) {
 		{
 			name: "merge-privilege",
 			mr: &gitlab.MergeRequest{
-				IID: 1,
+				BasicMergeRequest: gitlab.BasicMergeRequest{
+					IID: 1,
+				},
 				User: struct {
 					CanMerge bool "json:\"can_merge\""
 				}{CanMerge: false},
@@ -183,8 +199,10 @@ func Test_MRCheckErrors(t *testing.T) {
 		{
 			name: "conflicts",
 			mr: &gitlab.MergeRequest{
-				IID:          1,
-				HasConflicts: true,
+				BasicMergeRequest: gitlab.BasicMergeRequest{
+					IID:          1,
+					HasConflicts: true,
+				},
 			},
 			errOpts: MRCheckErrOptions{
 				Conflict: true,
@@ -209,28 +227,28 @@ func Test_getMRForBranchFails(t *testing.T) {
 	baseRepo := glrepo.NewWithHost("foo", "bar", "gitlab.com")
 
 	t.Run("API-call-failed", func(t *testing.T) {
-		api.ListMRs = func(_ *gitlab.Client, _ interface{}, _ *gitlab.ListProjectMergeRequestsOptions) ([]*gitlab.MergeRequest, error) {
+		api.ListMRs = func(client *gitlab.Client, projectID interface{}, opts *gitlab.ListProjectMergeRequestsOptions, listOpts ...api.CliListMROption) ([]*gitlab.BasicMergeRequest, error) {
 			return nil, errors.New("API call failed")
 		}
 
-		got, err := getMRForBranch(&gitlab.Client{}, baseRepo, "foo", "opened")
+		got, err := getMRForBranch(&gitlab.Client{}, mrOptions{baseRepo, "foo", "opened", true})
 		assert.Nil(t, got)
 		assert.EqualError(t, err, `failed to get open merge request for "foo": API call failed`)
 	})
 
 	t.Run("no-return", func(t *testing.T) {
-		api.ListMRs = func(_ *gitlab.Client, _ interface{}, _ *gitlab.ListProjectMergeRequestsOptions) ([]*gitlab.MergeRequest, error) {
-			return []*gitlab.MergeRequest{}, nil
+		api.ListMRs = func(client *gitlab.Client, projectID interface{}, opts *gitlab.ListProjectMergeRequestsOptions, listOpts ...api.CliListMROption) ([]*gitlab.BasicMergeRequest, error) {
+			return []*gitlab.BasicMergeRequest{}, nil
 		}
 
-		got, err := getMRForBranch(&gitlab.Client{}, baseRepo, "foo", "opened")
+		got, err := getMRForBranch(&gitlab.Client{}, mrOptions{baseRepo, "foo", "opened", true})
 		assert.Nil(t, got)
 		assert.EqualError(t, err, `no open merge request available for "foo"`)
 	})
 
 	t.Run("owner-no-match", func(t *testing.T) {
-		api.ListMRs = func(_ *gitlab.Client, _ interface{}, _ *gitlab.ListProjectMergeRequestsOptions) ([]*gitlab.MergeRequest, error) {
-			return []*gitlab.MergeRequest{
+		api.ListMRs = func(client *gitlab.Client, projectID interface{}, opts *gitlab.ListProjectMergeRequestsOptions, listOpts ...api.CliListMROption) ([]*gitlab.BasicMergeRequest, error) {
+			return []*gitlab.BasicMergeRequest{
 				{
 					IID: 1,
 					Author: &gitlab.BasicUser{
@@ -246,7 +264,7 @@ func Test_getMRForBranchFails(t *testing.T) {
 			}, nil
 		}
 
-		got, err := getMRForBranch(&gitlab.Client{}, baseRepo, "zemzale:foo", "opened")
+		got, err := getMRForBranch(&gitlab.Client{}, mrOptions{baseRepo, "zemzale:foo", "opened", true})
 		assert.Nil(t, got)
 		assert.EqualError(t, err, `no open merge request available for "foo" owned by @zemzale`)
 	})
@@ -258,12 +276,12 @@ func Test_getMRForBranch(t *testing.T) {
 	testCases := []struct {
 		name   string
 		input  string
-		mrs    []*gitlab.MergeRequest
+		mrs    []*gitlab.BasicMergeRequest
 		expect *gitlab.MergeRequest
 	}{
 		{
 			name: "one-match",
-			mrs: []*gitlab.MergeRequest{
+			mrs: []*gitlab.BasicMergeRequest{
 				{
 					IID: 1,
 					Author: &gitlab.BasicUser{
@@ -272,16 +290,18 @@ func Test_getMRForBranch(t *testing.T) {
 				},
 			},
 			expect: &gitlab.MergeRequest{
-				IID: 1,
-				Author: &gitlab.BasicUser{
-					Username: "profclems",
+				BasicMergeRequest: gitlab.BasicMergeRequest{
+					IID: 1,
+					Author: &gitlab.BasicUser{
+						Username: "profclems",
+					},
 				},
 			},
 		},
 		{
 			name:  "owner-match",
 			input: "maxice8:foo",
-			mrs: []*gitlab.MergeRequest{
+			mrs: []*gitlab.BasicMergeRequest{
 				{
 					IID: 1,
 					Author: &gitlab.BasicUser{
@@ -296,20 +316,22 @@ func Test_getMRForBranch(t *testing.T) {
 				},
 			},
 			expect: &gitlab.MergeRequest{
-				IID: 2,
-				Author: &gitlab.BasicUser{
-					Username: "maxice8",
+				BasicMergeRequest: gitlab.BasicMergeRequest{
+					IID: 2,
+					Author: &gitlab.BasicUser{
+						Username: "maxice8",
+					},
 				},
 			},
 		},
 	}
 	for _, tC := range testCases {
 		t.Run(tC.name, func(t *testing.T) {
-			api.ListMRs = func(_ *gitlab.Client, _ interface{}, _ *gitlab.ListProjectMergeRequestsOptions) ([]*gitlab.MergeRequest, error) {
+			api.ListMRs = func(_ *gitlab.Client, _ interface{}, _ *gitlab.ListProjectMergeRequestsOptions, listOpts ...api.CliListMROption) ([]*gitlab.BasicMergeRequest, error) {
 				return tC.mrs, nil
 			}
 
-			got, err := getMRForBranch(&gitlab.Client{}, baseRepo, tC.input, "opened")
+			got, err := getMRForBranch(&gitlab.Client{}, mrOptions{baseRepo, tC.input, "opened", true})
 			assert.NoError(t, err)
 
 			assert.Equal(t, tC.expect.IID, got.IID)
@@ -321,8 +343,8 @@ func Test_getMRForBranch(t *testing.T) {
 func Test_getMRForBranchPrompt(t *testing.T) {
 	baseRepo := glrepo.NewWithHost("foo", "bar", "gitlab.com")
 
-	api.ListMRs = func(_ *gitlab.Client, _ interface{}, _ *gitlab.ListProjectMergeRequestsOptions) ([]*gitlab.MergeRequest, error) {
-		return []*gitlab.MergeRequest{
+	api.ListMRs = func(client *gitlab.Client, projectID interface{}, opts *gitlab.ListProjectMergeRequestsOptions, listOpts ...api.CliListMROption) ([]*gitlab.BasicMergeRequest, error) {
+		return []*gitlab.BasicMergeRequest{
 			{
 				IID: 1,
 				Author: &gitlab.BasicUser{
@@ -349,7 +371,7 @@ func Test_getMRForBranchPrompt(t *testing.T) {
 			},
 		})
 
-		got, err := getMRForBranch(&gitlab.Client{}, baseRepo, "foo", "opened")
+		got, err := getMRForBranch(&gitlab.Client{}, mrOptions{baseRepo, "foo", "opened", true})
 		assert.NoError(t, err)
 
 		assert.Equal(t, 1, got.IID)
@@ -367,7 +389,7 @@ func Test_getMRForBranchPrompt(t *testing.T) {
 			},
 		})
 
-		got, err := getMRForBranch(&gitlab.Client{}, baseRepo, "foo", "opened")
+		got, err := getMRForBranch(&gitlab.Client{}, mrOptions{baseRepo, "foo", "opened", true})
 		assert.Nil(t, got)
 		assert.EqualError(t, err, "you must select a merge request: prompt failed")
 	})
@@ -379,17 +401,20 @@ func Test_MRFromArgsWithOpts(t *testing.T) {
 		HttpClient: func() (*gitlab.Client, error) { return &gitlab.Client{}, nil },
 		BaseRepo:   func() (glrepo.Interface, error) { return glrepo.New("foo", "bar"), nil },
 		Branch:     func() (string, error) { return "main", nil },
+		IO:         &iostreams.IOStreams{},
 	}
+	f.IO.SetPrompt("false")
 
 	t.Run("success", func(t *testing.T) {
 		t.Run("via-ID", func(t *testing.T) {
 			f := *f
-
 			api.GetMR = func(client *gitlab.Client, projectID interface{}, mrID int, opts *gitlab.GetMergeRequestsOptions) (*gitlab.MergeRequest, error) {
 				return &gitlab.MergeRequest{
-					IID:          2,
-					Title:        "test mr",
-					SourceBranch: "main",
+					BasicMergeRequest: gitlab.BasicMergeRequest{
+						IID:          2,
+						Title:        "test mr",
+						SourceBranch: "main",
+					},
 				}, nil
 			}
 
@@ -410,8 +435,8 @@ func Test_MRFromArgsWithOpts(t *testing.T) {
 		t.Run("via-name", func(t *testing.T) {
 			f := *f
 
-			getMRForBranch = func(apiClient *gitlab.Client, baseRepo glrepo.Interface, arg string, state string) (*gitlab.MergeRequest, error) {
-				return &gitlab.MergeRequest{
+			getMRForBranch = func(apiClient *gitlab.Client, mrOpts mrOptions) (*gitlab.BasicMergeRequest, error) {
+				return &gitlab.BasicMergeRequest{
 					IID:          2,
 					Title:        "test mr",
 					SourceBranch: "main",
@@ -420,9 +445,11 @@ func Test_MRFromArgsWithOpts(t *testing.T) {
 
 			api.GetMR = func(client *gitlab.Client, projectID interface{}, mrID int, opts *gitlab.GetMergeRequestsOptions) (*gitlab.MergeRequest, error) {
 				return &gitlab.MergeRequest{
-					IID:          2,
-					Title:        "test mr",
-					SourceBranch: "main",
+					BasicMergeRequest: gitlab.BasicMergeRequest{
+						IID:          2,
+						Title:        "test mr",
+						SourceBranch: "main",
+					},
 				}, nil
 			}
 
@@ -484,8 +511,8 @@ func Test_MRFromArgsWithOpts(t *testing.T) {
 		t.Run("invalid-name", func(t *testing.T) {
 			f := *f
 
-			getMRForBranch = func(apiClient *gitlab.Client, baseRepo glrepo.Interface, arg string, state string) (*gitlab.MergeRequest, error) {
-				return nil, fmt.Errorf("no merge requests from branch %q", arg)
+			getMRForBranch = func(_ *gitlab.Client, mrOpts mrOptions) (*gitlab.BasicMergeRequest, error) {
+				return nil, fmt.Errorf("no merge requests from branch %q", mrOpts.arg)
 			}
 
 			gotMR, gotRepo, err := MRFromArgs(&f, []string{"foo"}, "")
@@ -510,7 +537,7 @@ func Test_MRFromArgsWithOpts(t *testing.T) {
 
 func Test_DisplayAllMRs(t *testing.T) {
 	streams, _, _, _ := iostreams.Test()
-	mrs := []*gitlab.MergeRequest{
+	mrs := []*gitlab.BasicMergeRequest{
 		{
 			IID:          1,
 			State:        "opened",
@@ -589,6 +616,7 @@ func Test_PrintMRApprovalState(t *testing.T) {
 				},
 			},
 			expected: `Rule "rule 1" sufficient approvals (2/2 required):
+Name	Username	Approved
 User One	user1	👍	
 User Two	user2	👍	
 
@@ -614,6 +642,7 @@ User Two	user2	👍
 				},
 			},
 			expected: `Rule "rule 1" insufficient approvals (1/2 required):
+Name	Username	Approved
 User One	user1	👍	
 
 `,
@@ -655,6 +684,7 @@ User One	user1	👍
 				},
 			},
 			expected: `Rule "rule 1" sufficient approvals (2/2 required):
+Name	Username	Approved
 User One	user1	👍	
 User Two	user2	👍	
 
@@ -692,6 +722,7 @@ User Two	user2	👍
 				},
 			},
 			expected: `Rule "rule 1" insufficient approvals (1/2 required):
+Name	Username	Approved
 User One	user1	👍	
 User Two	user2	-	
 
@@ -732,6 +763,7 @@ User Two	user2	-
 				},
 			},
 			expected: `Rule "rule 1" sufficient approvals (4/2 required):
+Name	Username	Approved
 User Three	000	👍	
 User One	aaa	👍	
 User Four	xyz	👍	
@@ -786,6 +818,7 @@ User Two	zzz	👍
 				},
 			},
 			expected: `Rule "rule 1" sufficient approvals (4/2 required):
+Name	Username	Approved
 User Four	xyz	👍	
 User Two	zzz	👍	
 User Three	000	👍	
@@ -830,6 +863,7 @@ User One	aaa	👍
 				},
 			},
 			expected: `Rule "rule 1" sufficient approvals (2/2 required):
+Name	Username	Approved
 User Four	xyz	-	
 User Two	zzz	-	
 User Three	000	👍	
