@@ -9,7 +9,7 @@ import (
 	"gitlab.com/gitlab-org/cli/commands/mr/mrutils"
 
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 )
 
 func NewCmdReopen(f *cmdutils.Factory) *cobra.Command {
@@ -54,7 +54,7 @@ func NewCmdReopen(f *cmdutils.Factory) *cobra.Command {
 				}
 
 				fmt.Fprintf(f.IO.StdOut, "%s Reopened merge request !%d.\n", c.GreenCheck(), mr.IID)
-				fmt.Fprintln(f.IO.StdOut, mrutils.DisplayMR(f.IO.Color(), mr, f.IO.IsaTTY))
+				fmt.Fprintln(f.IO.StdOut, mrutils.DisplayMR(f.IO.Color(), &mr.BasicMergeRequest, f.IO.IsaTTY))
 			}
 
 			return nil
