@@ -3,7 +3,7 @@ package list
 import (
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
@@ -29,7 +29,7 @@ func NewCmdList(f *cmdutils.Factory, runE func(*ListOpts) error) *cobra.Command
 	}
 	cmd := &cobra.Command{
 		Use:   "list",
-		Short: "Get a list of currently authenticated user's SSH keys.",
+		Short: "Get a list of SSH keys for the currently authenticated user.",
 		Long:  "",
 		Example: heredoc.Doc(`
 		glab ssh-key list
@@ -47,9 +47,9 @@ func NewCmdList(f *cmdutils.Factory, runE func(*ListOpts) error) *cobra.Command
 		},
 	}
 
-	cmd.Flags().BoolVarP(&opts.ShowKeyIDs, "show-id", "", false, "Shows IDs of SSH Keys")
-	cmd.Flags().IntVarP(&opts.Page, "page", "p", 1, "Page number")
-	cmd.Flags().IntVarP(&opts.PerPage, "per-page", "P", 30, "Number of items to list per page")
+	cmd.Flags().BoolVarP(&opts.ShowKeyIDs, "show-id", "", false, "Shows IDs of SSH keys.")
+	cmd.Flags().IntVarP(&opts.Page, "page", "p", 1, "Page number.")
+	cmd.Flags().IntVarP(&opts.PerPage, "per-page", "P", 30, "Number of items to list per page.")
 
 	return cmd
 }
@@ -66,13 +66,21 @@ func listRun(opts *ListOpts) error {
 	}
 	keys, _, err := httpClient.Users.ListSSHKeys(sshKeyListOptions)
 	if err != nil {
-		return cmdutils.WrapError(err, "failed to get ssh keys")
+		return cmdutils.WrapError(err, "failed to get SSH keys.")
 	}
 
 	cs := opts.IO.Color()
 	table := tableprinter.NewTablePrinter()
 	isTTy := opts.IO.IsOutputTTY()
 
+	if len(keys) > 0 {
+		if opts.ShowKeyIDs {
+			table.AddRow("ID", "Title", "Key", "Usage type", "Created At")
+		} else {
+			table.AddRow("Title", "Key", "Usage type", "Created At")
+		}
+	}
+
 	for _, key := range keys {
 		createdAt := key.CreatedAt.String()
 		if opts.ShowKeyIDs {
@@ -81,7 +89,7 @@ func listRun(opts *ListOpts) error {
 		if isTTy {
 			createdAt = utils.TimeToPrettyTimeAgo(*key.CreatedAt)
 		}
-		table.AddRow(key.Title, key.Key, cs.Gray(createdAt))
+		table.AddRow(key.Title, key.Key, key.UsageType, cs.Gray(createdAt))
 	}
 
 	opts.IO.LogInfo(table.String())
