@@ -20,13 +20,15 @@ type ListOpts struct {
 	HTTPClient func() (*gitlab.Client, error)
 	IO         *iostreams.IOStreams
 	BaseRepo   func() (glrepo.Interface, error)
+	Page       int
+	PerPage    int
 
 	ValueSet     bool
 	Group        string
 	OutputFormat string
 }
 
-func NewCmdSet(f *cmdutils.Factory, runE func(opts *ListOpts) error) *cobra.Command {
+func NewCmdList(f *cmdutils.Factory, runE func(opts *ListOpts) error) *cobra.Command {
 	opts := &ListOpts{
 		IO: f.IO,
 	}
@@ -39,6 +41,9 @@ func NewCmdSet(f *cmdutils.Factory, runE func(opts *ListOpts) error) *cobra.Comm
 		Example: heredoc.Doc(
 			`
 			glab variable list
+			glab variable list --per-page 100 --page 1
+			glab variable list --group gitlab-org
+			glab variable list --group gitlab-org --per-page 100
 		`,
 		),
 		RunE: func(cmd *cobra.Command, args []string) (err error) {
@@ -69,6 +74,8 @@ func NewCmdSet(f *cmdutils.Factory, runE func(opts *ListOpts) error) *cobra.Comm
 		"Select a group or subgroup. Ignored if a repository argument is set.",
 	)
 	cmd.Flags().StringVarP(&opts.OutputFormat, "output", "F", "text", "Format output as: text, json.")
+	cmd.Flags().IntVarP(&opts.PerPage, "per-page", "P", 20, "Number of items to list per page.")
+	cmd.Flags().IntVarP(&opts.Page, "page", "p", 1, "Page number.")
 
 	return cmd
 }
@@ -80,17 +87,12 @@ func listRun(opts *ListOpts) error {
 		return err
 	}
 
-	repo, err := opts.BaseRepo()
-	if err != nil {
-		return err
-	}
-
 	table := tableprinter.NewTablePrinter()
-	table.AddRow("KEY", "PROTECTED", "MASKED", "EXPANDED", "SCOPE")
+	table.AddRow("KEY", "PROTECTED", "MASKED", "EXPANDED", "SCOPE", "DESCRIPTION")
 
 	if opts.Group != "" {
 		opts.IO.Logf("Listing variables for the %s group:\n\n", color.Bold(opts.Group))
-		createVarOpts := &gitlab.ListGroupVariablesOptions{}
+		createVarOpts := &gitlab.ListGroupVariablesOptions{Page: opts.Page, PerPage: opts.PerPage}
 		variables, err := api.ListGroupVariables(httpClient, opts.Group, createVarOpts)
 		if err != nil {
 			return err
@@ -101,12 +103,16 @@ func listRun(opts *ListOpts) error {
 
 		} else {
 			for _, variable := range variables {
-				table.AddRow(variable.Key, variable.Protected, variable.Masked, !variable.Raw, variable.EnvironmentScope)
+				table.AddRow(variable.Key, variable.Protected, variable.Masked, !variable.Raw, variable.EnvironmentScope, variable.Description)
 			}
 		}
 	} else {
+		repo, err := opts.BaseRepo()
+		if err != nil {
+			return err
+		}
 		opts.IO.Logf("Listing variables for the %s project:\n\n", color.Bold(repo.FullName()))
-		createVarOpts := &gitlab.ListProjectVariablesOptions{}
+		createVarOpts := &gitlab.ListProjectVariablesOptions{Page: opts.Page, PerPage: opts.PerPage}
 		variables, err := api.ListProjectVariables(httpClient, repo.FullName(), createVarOpts)
 		if err != nil {
 			return err
@@ -116,13 +122,13 @@ func listRun(opts *ListOpts) error {
 			fmt.Fprintln(opts.IO.StdOut, string(varListJSON))
 		} else {
 			for _, variable := range variables {
-				table.AddRow(variable.Key, variable.Protected, variable.Masked, !variable.Raw, variable.EnvironmentScope)
+				table.AddRow(variable.Key, variable.Protected, variable.Masked, !variable.Raw, variable.EnvironmentScope, variable.Description)
 			}
 		}
 	}
 
 	if opts.OutputFormat != "json" {
-		opts.IO.Log(table.String())
+		fmt.Fprint(opts.IO.StdOut, table.String())
 	}
 	return nil
 }
