@@ -37,6 +37,11 @@ func GetDefaultBranch(remote string) (string, error) {
 	return ParseDefaultBranch(output)
 }
 
+func RemoteBranchExists(branch string, gr GitRunner) bool {
+	_, err := gr.Git("ls-remote", "--exit-code", "--heads", DefaultRemote, branch)
+	return err == nil
+}
+
 func ParseDefaultBranch(output []byte) (string, error) {
 	var headBranch string
 
@@ -282,10 +287,13 @@ func ReadBranchConfig(branch string) (cfg BranchConfig) {
 	return
 }
 
-func DeleteLocalBranch(branch string) error {
-	branchCmd := GitCommand("branch", "-D", branch)
-	err := run.PrepareCmd(branchCmd).Run()
-	return err
+func DeleteLocalBranch(branch string, gr GitRunner) error {
+	_, err := gr.Git("branch", "-D", branch)
+	if err != nil {
+		return fmt.Errorf("could not delete local branch: %w", err)
+	}
+
+	return nil
 }
 
 func HasLocalBranch(branch string) bool {
@@ -294,10 +302,13 @@ func HasLocalBranch(branch string) bool {
 	return err == nil
 }
 
-func CheckoutBranch(branch string) error {
-	configCmd := GitCommand("checkout", branch)
-	err := run.PrepareCmd(configCmd).Run()
-	return err
+func CheckoutBranch(branch string, gr GitRunner) error {
+	_, err := gr.Git("checkout", branch)
+	if err != nil {
+		return fmt.Errorf("could not checkout branch: %w", err)
+	}
+
+	return nil
 }
 
 func CheckoutNewBranch(branch string) error {
@@ -306,26 +317,8 @@ func CheckoutNewBranch(branch string) error {
 	return err
 }
 
-func parseCloneArgs(extraArgs []string) (args []string, target string) {
-	args, target = parseArgs(extraArgs)
-	return
-}
-
-func parseArgs(cmdWithArgs []string) (args []string, command string) {
-	args = cmdWithArgs
-
-	if len(args) > 0 {
-		if !strings.HasPrefix(args[0], "-") {
-			command, args = args[0], args[1:]
-		}
-	}
-	return
-}
-
-func RunClone(cloneURL string, args []string) (target string, err error) {
-	cloneArgs, target := parseCloneArgs(args)
-
-	cloneArgs = append(cloneArgs, cloneURL)
+func RunClone(cloneURL string, target string, args []string) (cloneDir string, err error) {
+	cloneArgs := append(args, cloneURL)
 
 	// If the args contain an explicit target, pass it to clone
 	//    otherwise, parse the URL to determine where git cloned it to so we can return it
@@ -343,7 +336,7 @@ func RunClone(cloneURL string, args []string) (target string, err error) {
 	cloneCmd.Stderr = os.Stderr
 
 	err = run.PrepareCmd(cloneCmd).Run()
-	return
+	return target, err
 }
 
 func AddUpstreamRemote(upstreamURL, cloneDir string) error {
